@@ -13,6 +13,8 @@
 #' @param sampleBinSize sample size per bin
 #' @export
 #' @import ffbase
+#' @importFrom ff vw "vw<-" ff vmode is.factor.ff
+#' @importFrom bit chunk physical
 bin_data <- function( p, sortCol=1L, cols=seq_along(p$data), from=0, to=1
 					, nbins=100L
 					, decreasing = FALSE
@@ -103,13 +105,16 @@ bin_data <- function( p, sortCol=1L, cols=seq_along(p$data), from=0, to=1
 			bs <-binned_sum.ff(v, bin, nbins, INDEX=o)
 			
 			count <- bs[,1]
-			mean <- ifelse(count==0, NA, bs[,2] / count)
+			mean <- ifelse( count == 0, NA, bs[,2] / count)
 			na <- bs[,3] / (count + bs[,3])
+
+			b_sumsq <- binned_sumsq.ff(v, mean = mean, bin = bin, nbins = nbins, INDEX=o)
+			sd <- sqrt(b_sumsq[,2]/(count))
 			
-			if (is.logical(v)){
+			if (is.logical(v)){ ##????? will this be true considering previous if statement?
 				cbind(count, "FALSE"=(1-mean), "TRUE"=mean, "<NA>"=na)
 			} else {
-				cbind(count, mean=mean, complete = 1-na)
+				cbind(count, mean=mean, complete = 1-na, sd=sd)
 			}
 		}
 	})
